@@ -44,6 +44,7 @@ import (
 	"github.com/superfly/flyctl/internal/command/ssh"
 	"github.com/superfly/flyctl/internal/command/status"
 	"github.com/superfly/flyctl/internal/command/suspend"
+	"github.com/superfly/flyctl/internal/command/turboku"
 	"github.com/superfly/flyctl/internal/command/version"
 	"github.com/superfly/flyctl/internal/command/vm"
 	"github.com/superfly/flyctl/internal/command/volumes"
@@ -161,6 +162,7 @@ func New() *cobra.Command {
 		launch.New(),
 		info.New(),
 		jobs.New(),
+		turboku.New(),
 	}
 
 	// if os.Getenv("DEV") != "" {
